.. :changelog:

History
-------

0.1.0 (2015-08-12)
---------------------

* First release on PyPI.

0.2.0 (2015-08-14)
------------------

* Bytes handling fixes (Python3.3/Python2.4)
* Sanbobx testing
* Implemented new api endpoints
  * Card authorization and settlement
  * Transactions listing
  * Customers listing
  * Settlement accounts setup
  * Transaction acccounts setup
* Improved documentation
